==> gallery_1.5.orig.tar.gz: gallery-1.5.orig/nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: nls.php,v 1.38.8.1 2005/03/10 02:29:36 cryptographite Exp $
 */

/**
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist and it was 
 * maintained by Jan Schneider (jan@horde.org)
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */

/**
 ** Defaults
 **/

	$nls['language']['en_US'] =	'English (US)';

	$nls['postnuke']['en_US'] =     'eng';
	$nls['alias']['eng'] =          'en_US';

	$nls['phpnuke']['en_US']  =     'english';
	$nls['alias']['english']  =     'en_US';

/** 
 ** Charset
 **/
	
	$nls['default']['charset'] = 	'ISO-8859-1';
/**
 ** Direction
 **/
	
	$nls['default']['direction'] =	'ltr';

/**
 ** Alignment
 **/
	
	$nls['default']['alignment'] =	'left';
?>

==> gallery_1.5.1.orig.tar.gz: gallery-1.5.1.orig/nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: nls.php,v 1.40.2.2 2005/09/12 22:40:44 dmolavi Exp $
 */

/**
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist and it was 
 * maintained by Jan Schneider (jan@horde.org)
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 * @package	Language
 */

/* Defaults */
	$nls['language']['en_US'] =	'English (US)';

	$nls['postnuke']['en_US'] =     'eng';
	$nls['alias']['eng'] =          'en_US';

	$nls['phpnuke']['en_US']  =     'english';
	$nls['alias']['english']  =     'en_US';

	$nls['alias']['en']  =     'en_US';

/* Charset*/
	$nls['default']['charset'] = 	'ISO-8859-1';

/* Direction */
	$nls['default']['direction'] =	'ltr';

/* Alignment */
	$nls['default']['alignment'] =	'left';
?>
